address.format

# XMLRésuméLibrary: User Guide

XSL Parameter Reference | XSL Parameter Reference | css.href

## Name

address.format — controls default formatting of the `address` element

## Applies To

This parameter controls the formatting of the `address` element in all output formats.

## Possible Values

Possible values include `standard` (the default), `european`, and `italian`.

### Note

In the examples below, `<street>` means the value of XML element `<street>`, if defined. `<suburb | ward>` means the value of XML element `<suburb>`, if defined, otherwise the value of XML element `<ward>`, otherwise blank.

`standard`

  Formats addresses in North American layout:

  `<street>
  <street2>
  <suburb | ward>
  <city>, <state | province | county > <zip | postalCode>
  <country>`

`european`

  Formats addresses in European layout:

  `<street>
  <street2>
  <suburb | ward>
  <zip | postalCode> <city>, <state | province | county > <country>`

`italian`

  Formats addresses in Italian layout:

  `<street>
  <street2>
  <postalCode> <city> (<province>)
  <country>`

If none of these formats suit your needs, there is the option of entering your address as a single text block, in which case it will be formatted with line breaks intact. For example:

    <address>Sr. H&eacute;ctor Garc&iacute;a Mariz&oacute;
    Reina #35, apt. 4a, e/ Gervasio y Escobar
    Ciudad de La Habana, CP 11900
    CUBA</address>

XSL Parameter Reference | XSL Parameter Reference | css.href